@@ -1,3 +1,5 @@
+import sys
+import signal
 import time
 from datetime import datetime, timezone
 
@@ -9,9 +11,30 @@ from polaris.integrations import registered_rails_integration as rri
 
 
 logger = getLogger(__name__)
+DEFAULT_INTERVAL = 30
+TERMINATE = False
 
 
 class Command(BaseCommand):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        signal.signal(signal.SIGINT, self.exit_gracefully)
+        signal.signal(signal.SIGTERM, self.exit_gracefully)
+
+    @staticmethod
+    def exit_gracefully(sig, frame):
+        logger.info("Exiting poll_outgoing_transactions...")
+        module = sys.modules[__name__]
+        module.TERMINATE = True
+
+    @staticmethod
+    def sleep(seconds):
+        module = sys.modules[__name__]
+        for _ in range(seconds):
+            if module.TERMINATE:
+                break
+            time.sleep(1)
+
     def add_arguments(self, parser):
         parser.add_argument(
             "--loop",
@@ -23,17 +46,19 @@ class Command(BaseCommand):
             "-i",
             type=int,
             help=(
-                "The number of seconds to wait before "
-                "restarting command. Defaults to 30."
+                "The number of seconds to wait before restarting command. "
+                "Defaults to {}.".format(DEFAULT_INTERVAL)
             ),
-            default=30,
         )
 
     def handle(self, *args, **options):
+        module = sys.modules[__name__]
         if options.get("loop"):
             while True:
+                if module.TERMINATE:
+                    break
                 self.poll_outgoing_transactions()
-                time.sleep(options.get("interval"))
+                self.sleep(options.get("interval") or DEFAULT_INTERVAL)
         else:
             self.poll_outgoing_transactions()
 
