@@ -136,7 +136,7 @@ def parse_request_args(request: Request) -> Dict:
     except (ValueError, MemoInvalidException):
         return {"error": render_error_response(_("invalid 'memo' for 'memo_type'"))}
 
-    return {
+    args = {
         "asset": asset,
         "memo_type": memo_type,
         "memo": memo,
@@ -144,3 +144,10 @@ def parse_request_args(request: Request) -> Dict:
         "type": request.GET.get("type"),
         **extract_sep9_fields(request.GET),
     }
+
+    # add remaining extra params, it's on the anchor to validate them
+    for param, value in request.GET.items():
+        if param not in args:
+            args[param] = value
+
+    return args
